@@ -1,31 +1,29 @@
 #!/usr/bin/perl
 
-# Created by ./mk_str_mod.pl on Tue Sep 28 08:24:58 WEST 1999
+# Created by ./mk_str_mod.pl on Tue Aug  7 12:44:34 WEST 2001
 
 package Lingua::PT::VerbSuffixes ;
 use Exporter ;
 @ISA = qw(Exporter);
 @EXPORT = qw( $verb_suffixes );
 $verb_suffixes = <<EOSTR
-a cpres,1,uir,r,ir,uer,er
-a cpres,3,uir,r,ir,uer,er
+a cpres,1,er,ir,r,uer,uir
+a cpres,3,er,ir,r,uer,uir
 a imp,1,r
 a imp,3,r
-a ivo,2,ar
-a ivo,3,uir,r,ir,uer,er
+a ivo,3,er,ir,r,uer,uir
 a mdp,1,
 a mdp,3,
-a pres,3,ar
-ais cpres,5,uir,entir,r,edir,er,ir,uer,enir
-am cpres,6,uir,r,ir,uer,er
+ais cpres,5,edir,enir,entir,er,ir,r,uer,uir
+am cpres,6,er,ir,r,uer,uir
 am imp,6,r
-am ivo,6,uir,r,ir,uer,er
+am ivo,6,er,ir,r,uer,uir
 am mdp,6,
 am perf,6,
-amos cpres,4,uir,r,ir,uer,er
-amos ivo,4,uir,r,ir,uer,er
+amos cpres,4,er,ir,r,uer,uir
+amos ivo,4,er,ir,r,uer,uir
 arei fut,1,razer
-as cpres,2,uir,r,ir,uer,er
+as cpres,2,er,ir,r,uer,uir
 as imp,2,r
 as mdp,2,
 ce cpres,1,ar
@@ -85,11 +83,11 @@ em cfut,6,
 em cpres,6,ar
 em ivo,6,ar
 em pres,3,ir
-em pres,6,r,ir
+em pres,6,ir,r
 emos cpres,4,ar
 emos fut,4,
 emos ivo,4,ar
-emos perf,4,r,ar
+emos perf,4,ar,r
 enha cpres,1,ir
 enha cpres,3,ir
 enha ivo,3,ir
@@ -103,60 +101,60 @@ enhas ivo,2,ir
 enho pres,1,ir
 ens pres,2,ir
 envais cpres,5,onvir
-er cfut,1,r,ar
-er cfut,3,r,ar
+er cfut,1,ar,r
+er cfut,3,ar,r
 era imp,1,ser
 era imp,3,ser
-era mdp,1,r,ar
-era mdp,3,r,ar
+era mdp,1,ar,r
+era mdp,3,ar,r
 eram imp,6,ser
-eram mdp,6,r,ar
-eram perf,6,r,ar
+eram mdp,6,ar,r
+eram perf,6,ar,r
 eras imp,2,ser
-eras mdp,2,r,ar
-erem cfut,6,r,ar
-eres cfut,2,r,ar
-ermos cfut,4,r,ar
+eras mdp,2,ar,r
+erem cfut,6,ar,r
+eres cfut,2,ar,r
+ermos cfut,4,ar,r
 erto pp,1,rir
 es cfut,2,
 es cpres,2,ar
 es pres,2,ir
-esse cimp,1,r,ar
-esse cimp,3,r,ar
-essem cimp,6,r,ar
-esses cimp,2,r,ar
-esso pp,1,itir,imir
-este perf,2,r,ar
+esse cimp,1,ar,r
+esse cimp,3,ar,r
+essem cimp,6,ar,r
+esses cimp,2,ar,r
+esso pp,1,imir,itir
+este perf,2,ar,r
 estes perf,5,ar
 eu perf,3,ar
 evais cpres,5,over
 eve perf,3,ar
 ez perf,3,azer
-foi perf,3,ser,ir
-fomos perf,4,ser,ir
-for cfut,1,ser,ir
-for cfut,3,ser,ir
+foi perf,3,ir,ser
+fomos perf,4,ir,ser
+for cfut,1,ir,ser
+for cfut,3,ir,ser
 fora mdp,1,ser
 fora mdp,3,ser
 foram cfut,6,ir
 foram mdp,6,ser
-foram perf,6,ser,ir
+foram perf,6,ir,ser
 foras mdp,2,ser
-fordes cfut,5,ser,ir
+fordes cfut,5,ir,ser
 forem cfut,6,ser
-fores cfut,2,ser,ir
-formos cfut,4,ser,ir
-fosse cimp,1,ser,ir
-fosse cimp,3,ser,ir
-fossem cimp,6,ser,ir
-fosses cimp,2,ser,ir
-foste perf,2,ser,ir
-fostes perf,5,ser,ir
-fui perf,1,ser,ir
+fores cfut,2,ir,ser
+formos cfut,4,ir,ser
+fosse cimp,1,ir,ser
+fosse cimp,3,ir,ser
+fossem cimp,6,ir,ser
+fosses cimp,2,ir,ser
+foste perf,2,ir,ser
+fostes perf,5,ir,ser
+fui perf,1,ir,ser
 framos mdp,4,ser
 freis mdp,5,ser
-fsseis cimp,5,ser,ir
-fssemos cimp,4,ser,ir
+fsseis cimp,5,ir,ser
+fssemos cimp,4,ir,ser
 ga cpres,1,zer
 ga cpres,3,zer
 ga ivo,3,zer
@@ -255,7 +253,7 @@ igo pres,1,eguir
 ila cpres,1,elir
 ila cpres,3,elir
 ila ivo,3,elir
-ilais cpres,5,ler,elir
+ilais cpres,5,elir,ler
 ilam cpres,6,elir
 ilam ivo,6,elir
 ilamos cpres,4,elir
@@ -292,28 +290,28 @@ intamos ivo,4,entir
 intas cpres,2,entir
 inti ivo,5,entir
 into pres,1,entir
-io pres,1,r,ar
+io pres,1,ar,r
 ir cfut,1,er
 ir cfut,3,er
-ira cpres,1,rer,erir
-ira cpres,3,rer,erir
-ira ivo,3,rer,erir
+ira cpres,1,erir,rer
+ira cpres,3,erir,rer
+ira ivo,3,erir,rer
 ira mdp,1,er
 ira mdp,3,er
-irais cpres,5,rer,erir
-iram cpres,6,rer,erir
-iram ivo,6,rer,erir
+irais cpres,5,erir,rer
+iram cpres,6,erir,rer
+iram ivo,6,erir,rer
 iram mdp,6,er
 iram perf,6,er
-iramos cpres,4,rer,erir
-iramos ivo,4,rer,erir
-iras cpres,2,rer,erir
+iramos cpres,4,erir,rer
+iramos ivo,4,erir,rer
+iras cpres,2,erir,rer
 iras mdp,2,er
 irdes cfut,5,er
 irem cfut,6,er
 ires cfut,2,er
 irmos cfut,4,er
-iro pres,1,rer,erir
+iro pres,1,erir,rer
 irta cpres,1,ertir
 irta cpres,3,ertir
 irta ivo,3,ertir
@@ -447,17 +445,17 @@ iamos cpres,4,uvir
 iamos ivo,4,uvir
 ias cpres,2,uvir
 io pres,1,uvir
-ja cpres,1,r,gir,ver,ger
-ja cpres,3,r,gir,ver,ger
-ja ivo,3,r,gir,ver,ger
-jais cpres,5,r,gir,ver,ger
-jam cpres,6,r,gir,ver,ger
-jam ivo,6,r,gir,ver,ger
-jamos cpres,4,r,gir,ver,ger
-jamos ivo,4,r,gir,ver,ger
-jas cpres,2,r,gir,ver,ger
+ja cpres,1,ger,gir,r,ver
+ja cpres,3,ger,gir,r,ver
+ja ivo,3,ger,gir,r,ver
+jais cpres,5,ger,gir,r,ver
+jam cpres,6,ger,gir,r,ver
+jam ivo,6,ger,gir,r,ver
+jamos cpres,4,ger,gir,r,ver
+jamos ivo,4,ger,gir,r,ver
+jas cpres,2,ger,gir,r,ver
 jas ivo,2,ver
-jo pres,1,r,gir,ger
+jo pres,1,ger,gir,r
 jueado pp,1,guear
 jueai ivo,5,guear
 jueais pres,5,guear
@@ -525,9 +523,6 @@ m perf,1,r
 m perf,6,r
 m pres,3,r
 m pres,6,r
-medi ivo,5,pedir
-meam ivo,6,pedir
-meamos ivo,4,pedir
 mirdes cfut,5,r
 mos cfut,4,
 mos perf,4,r
@@ -552,12 +547,13 @@ nhas cpres,2,r
 nhas imp,2,r
 nho pres,1,r
 ns pres,2,r
-o pp,1,ivar,ar
-o pres,1,uir,r,ir,ar,uer,er
+o pp,1,ar,ivar
+o pres,1,ar,er,ir,r,uer,uir
 obe ivo,2,ubir
 obe pres,3,ubir
 obem pres,6,ubir
 obes pres,2,ubir
+oem pres,6,uir
 oge ivo,2,ugir
 oge pres,3,ugir
 ogem pres,6,ugir
@@ -565,7 +561,7 @@ oges pres,2,ugir
 oiemos cpres,4,iar
 oiemos ivo,4,iar
 ois pres,5,er
-omos pres,4,r,er
+omos pres,4,er,r
 onde ivo,5,r
 ondes pres,5,r
 ondo grd,1,r
@@ -760,7 +756,7 @@ reis cond,5,zer
 s perf,3,r
 s pres,2,r
 s pres,5,r
-so pp,1,nder,gir,der,ter,ir
+so pp,1,der,gir,ir,nder,ter
 ssa cpres,1,der
 ssa cpres,3,der
 ssa ivo,3,der
@@ -770,11 +766,11 @@ ssam ivo,6,der
 ssamos cpres,4,der
 ssamos ivo,4,der
 ssas cpres,2,der
-sse cimp,1,r,ir
-sse cimp,3,r,ir
+sse cimp,1,ir,r
+sse cimp,3,ir,r
 sse perf,1,zer
 sse perf,3,zer
-ssem cimp,6,r,ir
+ssem cimp,6,ir,r
 ssemos perf,4,zer
 sser cfut,1,zer
 sser cfut,3,zer
@@ -783,7 +779,7 @@ sserdes cfut,5,zer
 sserem cfut,6,zer
 sseres cfut,2,zer
 ssermos cfut,4,zer
-sses cimp,2,r,ir
+sses cimp,2,ir,r
 ssesse cimp,1,zer
 ssesse cimp,3,zer
 ssessem cimp,6,zer
@@ -795,7 +791,7 @@ ssssemos cimp,4,zer
 ste perf,2,r
 stes perf,5,r
 sto pp,1,r
-to pp,1,zer,gir,mper,guir,rer,gar,der,ir,ver
+to pp,1,der,gar,gir,guir,ir,mper,rer,ver,zer
 u perf,3,r
 ubra cpres,1,obrir
 ubra cpres,3,obrir
@@ -908,21 +904,21 @@ ramos mdp,4,ar
 reis mdp,5,ar
 s fut,2,
 s pres,2,ar,aver
-sseis cimp,5,ar,air
-ssemos cimp,4,ar,air
+sseis cimp,5,air,ar
+ssemos cimp,4,air,ar
 vamos imp,4,ar
 veis imp,5,ar
 o fut,6,
 o pres,6,ar,aver,er
-a cpres,1,vir,zer,cer,cir,dir
-a cpres,3,vir,zer,cer,cir,dir
-a ivo,3,zer,cer,cir,dir
-ais cpres,5,vir,zer,cer,cir,dir
-am cpres,6,vir,zer,cer,cir,dir
-am ivo,6,vir,zer,cer,cir,dir
-amos cpres,4,vir,zer,cer,cir,dir
-amos ivo,4,vir,zer,cer,cir,dir
-as cpres,2,vir,zer,cer,cir,dir
+a cpres,1,cer,cir,dir,vir,zer
+a cpres,3,cer,cir,dir,vir,zer
+a ivo,3,cer,cir,dir,zer
+ais cpres,5,cer,cir,dir,vir,zer
+am cpres,6,cer,cir,dir,vir,zer
+am ivo,6,cer,cir,dir,vir,zer
+amos cpres,4,cer,cir,dir,vir,zer
+amos ivo,4,cer,cir,dir,vir,zer
+as cpres,2,cer,cir,dir,vir,zer
 auteado pp,1,cautear
 auteai ivo,5,cautear
 auteais pres,5,cautear
@@ -984,7 +980,7 @@ autesseis cimp,5,cautear
 autessemos cimp,4,cautear
 autevamos imp,4,cautear
 auteveis imp,5,cautear
-o pres,1,vir,zer,cer,cir,dir
+o pres,1,cer,cir,dir,vir,zer
 oa ivo,2,coar
 oa pres,3,coar
 oado pp,1,coar
@@ -1052,7 +1048,7 @@ m ivo,2,er
 m pres,3,er
 ns pres,2,er
 ramos imp,4,ser
-ramos mdp,4,r,ar
+ramos mdp,4,ar,r
 reis imp,5,ser
 s pres,2,ser
 ssemos cimp,4,r
@@ -1065,7 +1061,7 @@ em cpres,6,ar
 em ivo,6,ar
 em pres,6,er
 ia ivo,3,er
-m pres,6,ir,er
+m pres,6,er,ir
 mos cpres,4,ar
 ramos mdp,4,er
 reis mdp,5,er
@@ -1074,23 +1070,23 @@ s pres,2,er
 sseis cimp,5,ar,er
 ssemos cimp,4,ar,er
  ivo,5,ir
- perf,1,ir,er
-a imp,1,ir,er
-a imp,3,ir,er
-am imp,6,ir,er
+ perf,1,er,ir
+a imp,1,er,ir
+a imp,3,er,ir
+am imp,6,er,ir
 amos cond,3,
 amos cond,4,
 amos cpres,4,ir
-amos imp,4,ir,er
-as imp,2,ir,er
-do pp,1,ir,er
+amos imp,4,er,ir
+as imp,2,er,ir
+do pp,1,er,ir
 eis cond,4,
 eis cond,5,
 eis cpres,5,ir
-eis imp,5,ir,er
+eis imp,5,er,ir
 mos perf,4,ir
 mos pres,4,ir
-nhamos imp,4,ir,er
+nhamos imp,4,er,ir
 nheis imp,5,er
 r cfut,1,ir
 r cfut,3,ir
@@ -1098,10 +1094,10 @@ ra mdp,1,ir
 ra mdp,3,ir
 ram mdp,6,ir
 ram perf,6,ir
-ramos mdp,4,ir,er
+ramos mdp,4,er,ir
 ras mdp,2,ir
 rdes cfut,5,ir
-reis mdp,5,ir,er
+reis mdp,5,er,ir
 rem cfut,6,ir
 res cfut,2,ir
 rmos cfut,4,ir
@@ -1118,21 +1114,22 @@ stes perf,5,ir
 sseis cimp,5,er
 ssemos cimp,4,er
 i ivo,2,oer
-i pres,3,oer
-ia ivo,2,oiar,iar
-ia pres,3,oiar,iar
-iais pres,5,oiar,iar
-iam pres,6,oiar,iar
-iamos pres,4,oiar,iar
-ias pres,2,oiar,iar
-ie cpres,1,oiar,iar
-ie cpres,3,oiar,iar
-ie ivo,3,oiar,iar
+i pres,3,oer,uir
+ia ivo,2,iar,oiar
+ia pres,3,iar,oiar
+iais pres,5,iar,oiar
+iam pres,6,iar,oiar
+iamos pres,4,iar,oiar
+ias pres,2,iar,oiar
+ie cpres,1,iar,oiar
+ie cpres,3,iar,oiar
+ie ivo,3,iar,oiar
 ieis cpres,5,iar
-iem cpres,6,oiar,iar
-iem ivo,6,oiar,iar
-ies cpres,2,oiar,iar
-io pres,1,oiar,iar
+iem cpres,6,iar,oiar
+iem ivo,6,iar,oiar
+ies cpres,2,iar,oiar
+io pres,1,iar,oiar
+is pres,2,uir
 de perf,3,oder
 s perf,3,or
 e ivo,2,or,r
